# Generated by Django 3.2.7 on 2021-09-22 12:52

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('changelog', '0001_initial'),
    ]

    operations = [
        migrations.AlterUniqueTogether(
            name='commit',
            unique_together=None,
        ),
        migrations.RemoveField(
            model_name='commit',
            name='branch',
        ),
        migrations.RemoveField(
            model_name='commit',
            name='created_by',
        ),
        migrations.RemoveField(
            model_name='human',
            name='user',
        ),
        migrations.DeleteModel(
            name='Branch',
        ),
        migrations.DeleteModel(
            name='Commit',
        ),
        migrations.DeleteModel(
            name='Human',
        ),
    ]
